---
name: BUG报告
about: 创建一个报告来帮助我们提高软件质量
title: ''
labels: ''
assignees: ''

---

**描述BUG**
清楚简洁地描述出现了什么BUG。

**复现方法**
描述复现BUG的步骤：
1. 
2. 
3. 
4. 

**希望的结果**
简洁清晰地描述你想要的结果。

**屏幕截图**
If applicable, add screenshots to help explain your problem.
如果有需要，请附上屏幕截图。

**桌面系统(请补充下列信息):**
 - 操作系统: [e.g. iOS]
 - 浏览器 [e.g. chrome, safari]
 - 版本号 [e.g. 22]

**附加内容**
关于本议题的其他内容。
